==> haskell-gi-gtk-hs-0.3.17-40-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-gtk-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-gtk-hs
version:              0.3.17
visibility:           public
id:                   gi-gtk-hs-0.3.17-DzU5MkpOG2M2CNfNiviXBy
key:                  gi-gtk-hs-0.3.17-DzU5MkpOG2M2CNfNiviXBy
license:              LGPL-2.1-only
maintainer:           mail@jonasplatte.de
author:
    Jonas Platte,
    Duncan Coutts,
    Axel Simon,
    Hamish Mackenzie,
    Iñaki García Etxebarria

homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

description:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

category:             Graphics
abi:                  2e92a733ebde7295fc8a1d8978fa7bea
exposed:              True
exposed-modules:
    Data.GI.Gtk Data.GI.Gtk.BuildFn Data.GI.Gtk.ComboBox
    Data.GI.Gtk.ModelView.CellLayout Data.GI.Gtk.ModelView.CustomStore
    Data.GI.Gtk.ModelView.ForestStore Data.GI.Gtk.ModelView.SeqStore
    Data.GI.Gtk.ModelView.TreeModel Data.GI.Gtk.ModelView.Types
    Data.GI.Gtk.Threading Data.GI.Gtk.Widget

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-gtk-hs
hs-libraries:         HSgi-gtk-hs-0.3.17-DzU5MkpOG2M2CNfNiviXBy
depends:
    base-4.17.2.1 base-compat-0.13.0-4bY7VGgUDQwFnN0OMsXbDp
    containers-0.6.7 gi-gdk-3.0.28-62DCFwj5oFjIWUWolcCMu4
    gi-gdkpixbuf-2.0.32-4FUmshMITOHFZ79YlCV4yU
    gi-glib-2.0.30-2CcwaoGPfUAIFbC65XZJMu
    gi-gobject-2.0.31-2136N1BlehZHaO9cs8uo4v
    gi-gtk-3.0.39-4qNaV65Ldpb4GRq52TaXHb
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gi-gtk-hs/html/gi-gtk-hs.haddock
haddock-html:         /usr/share/doc/haskell-gi-gtk-hs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-gtk-hs-0.3.17-41-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-gtk-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-gtk-hs
version:              0.3.17
visibility:           public
id:                   gi-gtk-hs-0.3.17-7jlH1hX6BDYGQOz7F0sPWF
key:                  gi-gtk-hs-0.3.17-7jlH1hX6BDYGQOz7F0sPWF
license:              LGPL-2.1-only
maintainer:           mail@jonasplatte.de
author:
    Jonas Platte,
    Duncan Coutts,
    Axel Simon,
    Hamish Mackenzie,
    Iñaki García Etxebarria

homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

description:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

category:             Graphics
abi:                  934bacf2f326ee1eb1f2d4d72d366a2d
exposed:              True
exposed-modules:
    Data.GI.Gtk Data.GI.Gtk.BuildFn Data.GI.Gtk.ComboBox
    Data.GI.Gtk.ModelView.CellLayout Data.GI.Gtk.ModelView.CustomStore
    Data.GI.Gtk.ModelView.ForestStore Data.GI.Gtk.ModelView.SeqStore
    Data.GI.Gtk.ModelView.TreeModel Data.GI.Gtk.ModelView.Types
    Data.GI.Gtk.Threading Data.GI.Gtk.Widget

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-gtk-hs
hs-libraries:         HSgi-gtk-hs-0.3.17-7jlH1hX6BDYGQOz7F0sPWF
depends:
    base-4.17.2.1 base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    containers-0.6.7 gi-gdk-3.0.28-evzH2gZIEF5IzBXahlyV2
    gi-gdkpixbuf-2.0.32-HHmaG1yHj3P8CSdVGyVvbj
    gi-glib-2.0.30-KuHKhGhvuzv3SdIsClRYy4
    gi-gobject-2.0.31-5qYGfFrmNMHGQ8qKArkJft
    gi-gtk-3.0.39-6mhYPlkHGXTCGFsDXYT0bT
    haskell-gi-base-0.26.7-IKgSSFp3EiO52VN49Ye8zT mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gi-gtk-hs/html/gi-gtk-hs.haddock
haddock-html:         /usr/share/doc/haskell-gi-gtk-hs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
